package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.annotation.DataUpdateCheck;
import com.ruoyi.project.business.domain.TpAreaParaStandard;
import com.ruoyi.project.business.domain.vo.paramSelectItem.ElevatorModeParamlVo;
import com.ruoyi.project.business.service.ITpAreaParaStandardService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-04-26
 */
@RestController
@RequestMapping("/business/elevatorStand")
public class TpAreaParaStandardController extends BaseController
{
    @Autowired
    private ITpAreaParaStandardService tpAreaParaStandardService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpAreaParaStandard tpAreaParaStandard)
    {
        startPage();
        List<TpAreaParaStandard> list = tpAreaParaStandardService.selectTpAreaParaStandardList(tpAreaParaStandard);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpAreaParaStandard tpAreaParaStandard)
    {
        List<TpAreaParaStandard> list = tpAreaParaStandardService.selectTpAreaParaStandardList(tpAreaParaStandard);
        ExcelUtil<TpAreaParaStandard> util = new ExcelUtil<TpAreaParaStandard>(TpAreaParaStandard.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpAreaParaStandardService.selectTpAreaParaStandardById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpAreaParaStandard tpAreaParaStandard)
    {
        return toAjax(tpAreaParaStandardService.insertTpAreaParaStandard(tpAreaParaStandard));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TpAreaParaStandard tpAreaParaStandard)
    {
        return toAjax(tpAreaParaStandardService.updateTpAreaParaStandard(tpAreaParaStandard));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:standard:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpAreaParaStandardService.deleteTpAreaParaStandardByIds(ids));
    }

    /**
     * 新增或修改梯形参数默认数据
     */
    // @PreAuthorize("@ss.hasPermi('business:modelParaSelect:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @DataUpdateCheck(key = "id", tableName = "tp_elevator_model")
    @PostMapping("/updateModelStand")
    public AjaxResult editParam(@RequestBody ElevatorModeParamlVo paramlVo)
    {
        String res = tpAreaParaStandardService.updateModelParamStandard(paramlVo);
        if(StringUtils.isEmpty(res)){
            return AjaxResult.success();
        }
        return AjaxResult.error(res);
    }
}
